==> aliyun-python-sdk-ims-1.0.0.tar.gz: aliyun-python-sdk-ims-1.0.0/aliyunsdkims/request/v20170430/EnableVirtualMFARequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class EnableVirtualMFARequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ims', '2017-04-30', 'EnableVirtualMFA','Ims')

	def get_UserPrincipalName(self):
		return self.get_query_params().get('UserPrincipalName')

	def set_UserPrincipalName(self,UserPrincipalName):
		self.add_query_param('UserPrincipalName',UserPrincipalName)

	def get_AuthenticationCode(self):
		return self.get_query_params().get('AuthenticationCode')

	def set_AuthenticationCode(self,AuthenticationCode):
		self.add_query_param('AuthenticationCode',AuthenticationCode)

	def get_VirtualMFAKey(self):
		return self.get_query_params().get('VirtualMFAKey')

	def set_VirtualMFAKey(self,VirtualMFAKey):
		self.add_query_param('VirtualMFAKey',VirtualMFAKey)

==> aliyun-python-sdk-ims-1.0.1.tar.gz: aliyun-python-sdk-ims-1.0.1/aliyunsdkims/request/v20170430/EnableVirtualMFARequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class EnableVirtualMFARequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ims', '2017-04-30', 'EnableVirtualMFA','ims')

	def get_UserPrincipalName(self):
		return self.get_query_params().get('UserPrincipalName')

	def set_UserPrincipalName(self,UserPrincipalName):
		self.add_query_param('UserPrincipalName',UserPrincipalName)

	def get_AuthenticationCode(self):
		return self.get_query_params().get('AuthenticationCode')

	def set_AuthenticationCode(self,AuthenticationCode):
		self.add_query_param('AuthenticationCode',AuthenticationCode)

	def get_VirtualMFAKey(self):
		return self.get_query_params().get('VirtualMFAKey')

	def set_VirtualMFAKey(self,VirtualMFAKey):
		self.add_query_param('VirtualMFAKey',VirtualMFAKey)
